CHANGES
=======

1.2
------

- Removed support for Django 1.2. It should still work, but it's not supported. 
- We now require icalendar 3.1.
- Added support for the GEO field. *Thanks, null_radix!*

1.1
------

- Fixed issues running tests on Django 1.2 and Django 1.5.

1.0
-------

- Initial Release
